{% load admin_urls i18n import_export_tags %}

{% block confirm_import_form %}
    <form action="{% url opts|admin_urlname:"process_import" %}" method="post" class="border border-base-200 mb-8 rounded-default shadow-xs dark:border-base-800">
        {% csrf_token %}

        {{ confirm_form.as_p }}

        <p class="font-semibold p-4 text-sm text-base-900 dark:text-base-100">
            {% trans "Below is a preview of data to be imported. If you are satisfied with the results, click 'Confirm import'" %}
        </p>

        <div class="border-t border-base-200 flex flex-row px-4 py-3 dark:border-base-800">
            <button type="submit" class="bg-primary-600 border border-transparent font-medium ml-auto px-3 py-2 rounded-default text-sm text-white">
                {% translate 'Confirm import' %}
            </button>
        </div>
    </form>
{% endblock %}
