{% load admin_urls i18n %}

{% if show_back_button %}
    {% if opts and adminform %}
        {% url opts|admin_urlname:'changelist' as changelist_url %}

        <a href="{% add_preserved_filters changelist_url %}" class="block h-[18px] mr-3" title="{% trans "Go back" %}">
            <span class="material-symbols-outlined">
                arrow_back
            </span>
        </a>
    {% endif %}
{% endif %}
